SWDEV-333188 - Port image tests to catch2 (#2793)
- Port image tests to catch2. - Disable 3D filter test for gfx9a. - Some other improvement - Temporarily disable linear filter tests on Windows Change-Id: Ieeddac9f8c50aa9b6b12ca9d8fd792a51973b8ca
This commit is contained in:
committed by
GitHub
parent
9e84a11f23
commit
f3c171c984
@@ -22,14 +22,18 @@ THE SOFTWARE.
|
||||
#define N 512
|
||||
|
||||
static __global__ void tex1dKernel(float *val, hipTextureObject_t obj) {
|
||||
int k = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
if (k < N) {
|
||||
val[k] = tex1Dfetch<float>(obj, k);
|
||||
}
|
||||
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
|
||||
int k = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
if (k < N) {
|
||||
val[k] = tex1Dfetch<float>(obj, k);
|
||||
}
|
||||
#endif
|
||||
}
|
||||
|
||||
|
||||
TEST_CASE("Unit_hipCreateTextureObject_tex1DfetchVerification") {
|
||||
CHECK_IMAGE_SUPPORT
|
||||
|
||||
// Allocating the required buffer on gpu device
|
||||
float *texBuf, *texBufOut;
|
||||
float val[N], output[N];
|
||||
|
||||
Reference in New Issue
Block a user